@@ -1,5 +1,5 @@
 # Copyright (c) 2012 Jasper Lievisse Adriaanse <jasper@mtier.org>
-# Copyright (c) 2012-2013 M:tier Ltd.
+# Copyright (c) 2012 M:tier Ltd.
 #
 # Permission to use, copy, modify, and distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -26,48 +26,23 @@ use vars qw(@ISA @EXPORT $VERSION);
 @ISA    = qw( Exporter );
 @EXPORT = qw( &puppettidy );
 
-$VERSION = '0.3.2';
+$VERSION = '0.1';
 
 my %config = (
-    output_type   => 'file',
-    output_ext    => 'tdy',
+    output_type => 'file',
+    output_ext  => 'tdy',
     output_stream => undef,
-    input_files   => undef,
-    input_stream  => undef,
-    validate      => 0,
-);
-
-# Array of supported checks along with a short description. We cannot use
-# a hash here because we must preserve order.
-my @checks = (
-    {"func"  => \&expand_tabs,
-     "descr" => "Expand tabs"},
-    {"func"  => \&commenting,
-     "descr" => "Commenting"},
-    {"func"  => \&trailing_whitespace,
-     "descr" => "Trailing whitespace"},
-    {"func"  => \&variable_string,
-     "descr" => "Variable string"},
-    {"func"  => \&quotes_resource_ref_type,
-     "descr" => "Resource reference type quoting"},
-    {"func"  => \&quotes_title,
-     "descr" => "Title quoting"},
-    {"func"  => \&quotes_attribute,
-     "descr" => "Attribute quoting"},
-    {"func"  => \&handle_modes,
-     "descr" => "Four digit mode"},
-    {"func"  => \&quoted_booleans,
-     "descr" => "Quoted booleans"},
+    input_files => undef,
+    input_stream => undef,
 );
 
 sub puppettidy(%){
     my %defaults = (
-	argv        => undef,
-	source      => undef,
+	argv => undef,
+	source => undef,
 	destination => undef,
     );
 
-    # Merge arguments over our defaults.
     my %args_hash = @_;
     %args_hash = (%defaults, %args_hash);
 
@@ -98,46 +73,36 @@ sub puppettidy(%){
 	    @input = $config{'input_stream'};
 	}
 
-	for (my $c = 0; $c <= $#checks; $c++){
-	    $checks[$c]{"func"}->(\@input);
-	}
+	expand_tabs(\@input);
+	commenting(\@input);
+	trailing_whitespace(\@input);
+	variable_string(\@input);
+	quotes_resource_ref_type(\@input);
+	quotes_title(\@input);
+	quotes_attribute(\@input);
+	handle_modes(\@input);
 
 	if ($config{'output_type'} eq "file") {
-	    open(OF, ">$file.tdy") or
-		die("Cannot open $file.tdy for writing: $!");
-
+	    open(OF, ">$file.tdy") or die("Cannot open $file.tdy for writing: $!");
 	    foreach my $line (@input)
 	    {
 		print OF $line;
 	    }
 	    close(OF);
-	    pp_validate("$file.tdy");
 	} else {
 	    @{$config{'output_stream'}} = @input;
 	}
     }
 }
 
-sub list_checks()
-{
-    print("Supported checks:\n");
-    for (my $c = 0; $c <= $#checks; $c++){
-	print("\t" . $checks[$c]{"descr"} . "\n");
-    }
-
-    exit(0);
-}
-
 sub usage()
 {
     print STDERR << "EOF";
 Puppet::Tidy $VERSION
-usage: $0 [-chl] [file ...]
-	-c      : Check/validate the output with "puppet parser validate".
+usage: $0 [-h] [file ...]
 	-h	: Show this help message.
-	-l	: List supported checks.
 EOF
-    exit(1);
+    exit 1;
 }
 
 sub parse_options(@)
@@ -145,21 +110,10 @@ sub parse_options(@)
     require Getopt::Std;
 
     my %opt;
-    Getopt::Std::getopts('chl', \%opt);
+    Getopt::Std::getopts('h', \%opt);
 
-    list_checks() if defined($opt{l});
     usage() if defined($opt{h}) or (@ARGV < 1);
 
-    if (defined($opt{c})) {
-	# Make sure puppet is installed
-	unless (grep { -x "$_/puppet"}split /:/,$ENV{PATH}) {
-	    print STDERR "Puppet is not installed or cannot be run. Make sure it's in your \$PATH.\n";
-	    exit(127);
-	}
-
-	$config{'validate'} = 1;
-    }
-
     # Check if input files are readable at all up front.
     foreach my $f (@ARGV) {
 	my $mode = (stat($f))[2];
@@ -167,21 +121,11 @@ sub parse_options(@)
 	    push(@{$config{'input_files'}}, $f);
 	} else {
 	    print "ERROR: $f is not readable or does not exist.\n";
-	    exit(1);
+	    exit 127;
 	}
     }
 }
 
-# Check the output of Puppet::Tidy with "puppet parser validate".
-sub pp_validate($)
-{
-    my $file = shift;
-
-    open(PP, "puppet parser validate $file |") or
-	die("Failed to validate manifest: $!\n");
-    close(PP);
-}
-
 # Expand literal tabs to two spaces
 sub expand_tabs(@)
 {
@@ -191,7 +135,7 @@ sub expand_tabs(@)
     @$input = Text::Tabs::expand(@$input);
 }
 
-# Remove trailing whitespace.
+# remove trailing whitespace
 sub trailing_whitespace(@)
 {
     my $input = shift;
@@ -201,31 +145,21 @@ sub trailing_whitespace(@)
     }
 }
 
-# Quoted strings containing only a variable shouldn't be quoted, also
-# single quoted strings containing a variable must be double quoted.
+# quoted strings containing only a variable shouldn't be quoted
 sub variable_string(@)
 {
     my $input = shift;
 
     foreach my $line (@$input)
     {
-	# Skip commented lines.
 	next if (($line eq "\n") or ($line =~ m/^#/));
-
-	# XXX: RT #6100, don't unquote password hashes.
-	next if ($line =~ m/password(\s+)=>/);
-
-	# Remove double quotes around a standalone variable
 	$line =~ s/"\$\{(.*?)\}"/\$\{$1\}/g;
 	$line =~ s/"\$(.*?)"/\$$1/g;
-
-	# Remove single quotes around a standalone variable
-	$line =~ s/\x27\$(.*?)\x27/\$$1/g;
     }
 }
 
-# Gix double quotes when used when references resources (File, Group, etc).
-# Bariables were already removed in the previous step so we can't have
+# fix double quotes when used when references resources (File, Group, etc).
+# variables were already removed in the previous step so we can't have
 # a Package["$pkg"] here anymore.
 sub quotes_resource_ref_type(@)
 {
@@ -249,8 +183,6 @@ sub quotes_title(@)
     foreach my $line (@$input) {
 	next if $line =~ m/\s*path/; # XXX: Tighten regexps below and remove me
 	next if $line =~ m/\s*command/;  # XXX: Tighten regexps below and remove me
-	next if ($line =~ m/\:\:/); # XXX: Skip lines with qualified variables
-
 	# Strings with a variable should be double quoted, but care
 	# must be taken if it's alse single quoted which is wrong anyway.
 	if ($line =~ m/\$.*?:(\s*|$)/) {
@@ -258,18 +190,18 @@ sub quotes_title(@)
 	    next if $line =~ s/(\$\w+)/"$1"/g;
 	}
 	$line =~ s/"(.*?)":/\x27$1\x27:/g; # Double to single quoted
-	$line =~ s/(?!['"])(\w+):(?!.+['"]+)/\x27$1\x27:/g; # Bare word to single quoted
+	$line =~ s/(\w+):/\x27$1\x27:/g; # Bare word to single quoted
     }
 }
 
-# Certain attributes should be single quoted, unless it is, or contains
+# certain attributes should be single quoted, unless it is, or contains
 # a variable.
 sub quotes_attribute(@)
 {
     my $input = shift;
     my @attributes = qw(mode path); # XXX: non-exhaustive list
 
-    # "Bare" to single quoted with no variables.
+    # "bare" to single quoted with no variables
     foreach my $line (@$input) {
 	next if $line =~ m/\$/;
 	foreach my $attr (@attributes)
@@ -278,7 +210,7 @@ sub quotes_attribute(@)
 	}
     }
 
-    # Double quoted to single quoted with no variables.
+    # double quoted to single quoted with no variables
     foreach my $line (@$input) {
 	next unless $line =~ m/=\> "/;
 	next if $line =~ m/\$/;
@@ -288,7 +220,7 @@ sub quotes_attribute(@)
 	}
     }
 
-    # Variables should be double quoted for string interpolation,
+    # variables should be double quoted for string interpolation,
     # which won't be done for at least mode since it's fully nummeric.
     foreach my $line (@$input) {
 	next unless (($line =~ m/=\> '/) and ($line =~ m/\$/));
@@ -320,33 +252,11 @@ sub commenting(@)
 
     foreach my $line (@$input)
     {
-	$line =~ s,(?!['"].+)//(?!.+['"]),#,; # C++ style
+	$line =~ s,//,#,; # C++ style
 	$line =~ s,/\*(.*?)(\s+)\*/,#$1,; # C style
     }
 }
 
-# Insert a warning regarding quoted booleans. The lines aren't actually
-# changed since this will change the meaning of the statement, so instead
-# we just insert an XXX.
-sub quoted_booleans(@)
-{
-    my $input = shift;
-
-    foreach my $line (@$input)
-    {
-	next unless ($line =~ /(\x27|\x22)(false|true)(\x27|\x22)/);
-
-	if ($line =~ /false/) {
-	    $line =~ s/\R//g;
-	    $line = $line . " # XXX: Quoted boolean encountered.\n";
-	}
-
-	if ($line =~ /true/) {
-	    $line =~ s/(\x22|\x27)true(\x22|\x27)/true/g;
-	}
-    }
-}
-
 1;
 
 __END__
@@ -417,13 +327,6 @@ Currently the following checks are implemented:
     Although Puppet supports C (/**/) and C++ (//) style comments, it's
     advised to use regular Puppet comments which use a pound sign (#).
 
-=head2 quoted_booleans
-
-    Booleans mustn't be quoted, since this means they're not nil, and will
-    thus evaluate to true. These errors are not fixed by Puppet::Tidy since
-    changing 'false' to true actually changing the meaning of a statement.
-    Instead, a warning is inserted into the file.
-
 =head1 LICENSE
 
 This module is free software, can you redistribute it and/or modify it
